==> blesta-5.10.2.zip: blesta/plugins/domains/language/tr_tr/domains_tlds.php <==
<?php
/**
 * Domains Tlds
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DomainsTlds.getTldFields.group'] = 'Grup';
$lang['DomainsTlds.!error.feature.unsupported'] = '1$s özelliği seçilen kayıt memuru modülü tarafından desteklenmiyor.';
$lang['DomainsTlds.!error.tld.supported'] = 'Sağlanan TLD, seçilen kayıt kuruluşu modülü tarafından desteklenmiyor.';
$lang['DomainsTlds.!error.package_pricing.service'] = 'Fiyatlandırma devre dışı bırakılamadı çünkü şu anda bir hizmet bunu kullanıyor.';
$lang['DomainsTlds.!error.package_pricing.count'] = 'Fiyatlandırma devre dışı bırakılamaz, TLD en az bir fiyatlandırmaya sahip olmalıdır.';
$lang['DomainsTlds.!error.epp_code.valid'] = 'EPP Kodu için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.id_protection.valid'] = 'Kimlik Koruması için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.email_forwarding.valid'] = 'E-posta Yönlendirme için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.dns_management.valid'] = 'DNS Yönetimi için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.commpany_id.exists'] = 'Geçersiz şirket kimliği.';
$lang['DomainsTlds.!error.module_id.exists'] = 'Geçersiz modül kimliği.';
$lang['DomainsTlds.!error.package_group_id.exists'] = 'Geçersiz paket grubu kimliği.';
$lang['DomainsTlds.!error.package_id.exists'] = 'Geçersiz paket kimliği.';
$lang['DomainsTlds.!error.tld_id.exists'] = 'Geçersiz TLD Kimliği.';
$lang['DomainsTlds.!error.tld.length'] = 'TLD en az 3 karakter uzunluğunda olmalıdır.';
$lang['DomainsTlds.!error.tld.not_exists'] = 'TLD şirkette mevcut değildir.';
$lang['DomainsTlds.!error.tld.exists'] = 'TLD şirkette zaten mevcuttur.';
$lang['DomainsTlds.!error.tld.empty'] = 'Lütfen bir TLD girin.';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/tr_tr/domains_tlds.php <==
<?php
/**
 * Domains Tlds
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DomainsTlds.getTldFields.group'] = 'Grup';
$lang['DomainsTlds.!error.tld.supported'] = 'Sağlanan TLD, seçilen kayıt kuruluşu modülü tarafından desteklenmiyor.';
$lang['DomainsTlds.!error.package_pricing.service'] = 'Fiyatlandırma devre dışı bırakılamadı çünkü şu anda bir hizmet bunu kullanıyor.';
$lang['DomainsTlds.!error.package_pricing.count'] = 'Fiyatlandırma devre dışı bırakılamaz, TLD en az bir fiyatlandırmaya sahip olmalıdır.';
$lang['DomainsTlds.!error.epp_code.valid'] = 'EPP Kodu için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.id_protection.valid'] = 'Kimlik Koruması için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.email_forwarding.valid'] = 'E-posta Yönlendirme için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.dns_management.valid'] = 'DNS Yönetimi için geçersiz değer, 0 veya 1 olmalıdır.';
$lang['DomainsTlds.!error.commpany_id.exists'] = 'Geçersiz şirket kimliği.';
$lang['DomainsTlds.!error.module_id.exists'] = 'Geçersiz modül kimliği.';
$lang['DomainsTlds.!error.package_group_id.exists'] = 'Geçersiz paket grubu kimliği.';
$lang['DomainsTlds.!error.package_id.exists'] = 'Geçersiz paket kimliği.';
$lang['DomainsTlds.!error.tld_id.exists'] = 'Geçersiz TLD Kimliği.';
$lang['DomainsTlds.!error.tld.length'] = 'TLD en az 3 karakter uzunluğunda olmalıdır.';
$lang['DomainsTlds.!error.tld.not_exists'] = 'TLD şirkette mevcut değildir.';
$lang['DomainsTlds.!error.tld.exists'] = 'TLD şirkette zaten mevcuttur.';
$lang['DomainsTlds.!error.tld.empty'] = 'Lütfen bir TLD girin.';
$lang['DomainsTlds.!error.feature.unsupported'] = '%1$s özelliği seçilen kayıt memuru modülü tarafından desteklenmiyor.';
